==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de Nube Federada inválida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirás una invitación. Comprueba tus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un compartido federado, parece ser que el servidor a federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar compartidos de grupos federados desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Compartir %1$s ha fallado porque este objeto ya se comparte con %2$s",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has recibido \"/%3$s\" como un recurso compartido remoto de %1$s (en nombre de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Has recibido \"%3$s\" como un compartido remoto de %1$s",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "Open documentation" : "Documentación abierta",
    "Adjust how people can share between servers." : "Ajusta cómo la gente puede compartir entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir a usuarios de este servidor compartir con usuarios de otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a usuarios de este servidor recibir archivos de usuarios de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar recursos compartidos a grupos en otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir compartidos de grupo desde otros servidores",
    "Search global and public address book for users" : "Buscar libretas de contactos globales y públicas para usuarios",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar su información en la libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puedes compartir con cualquiera que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM). Simplemente, pon su ID de Nube Federada en el diálogo de compartir. Es algo como persona@nube.ejemplo.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/es.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Deseas añadir el recurso compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Recurso compartido remoto",
    "Remote share password" : "Contraseña del compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Añadir recurso compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "ID de Nube Federada inválida",
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No se puede añadir un compartido remoto",
    "Couldn't establish a federated share, maybe the password was wrong." : "No se pudo establecer un compartido remoto, puede que la contraseña fuera incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Petición de recurso compartido federado enviada, recibirás una invitación. Comprueba tus notificaciones.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No se ha podido establecer un compartido federado, parece ser que el servidor a federar es demasiado antiguo (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No está permitido enviar compartidos de grupos federados desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Compartir %1$s ha fallado porque este objeto ya se comparte con %2$s",
    "Not allowed to create a federated share with the same user" : "No se permite crear un recurso compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya está siendo compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Compartir %1$s ha fallado, no se ha podido encontrar %2$s, quizás el servidor no se puede alcanzar ahora mismo o usa un certificado autofirmado.",
    "Could not find share" : "No se ha podido encontrar el compartido",
    "Federated sharing" : "Compartido federado",
    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Has recibido \"%3$s\" como recurso remoto comparitdo de %4$s (%1$s) (en nombre de %5$s (%2$s))",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un recurso compartido remoto de {user} (en nombre de {behalf})",
    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Has recibido \"%3$s\" como un recurso compartido remoto de %4$s (%1$s)",
    "You received {share} as a remote share from {user}" : "Has recibido {share} como un compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Denegar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartirlo conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartir",
    "Federated file sharing" : "Compartir federado",
    "Provide federated file sharing across servers" : "Provee compartición federada de archivos entre servidores",
    "Federated Cloud Sharing" : "Compartido en Cloud Federado",
    "Open documentation" : "Documentación abierta",
    "Adjust how people can share between servers." : "Ajusta cómo la gente puede compartir entre servidores.",
    "Allow users on this server to send shares to other servers" : "Permitir a usuarios de este servidor compartir con usuarios de otros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir a usuarios de este servidor recibir archivos de usuarios de otros servidores",
    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar recursos compartidos a grupos en otros servidores",
    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir compartidos de grupo desde otros servidores",
    "Search global and public address book for users" : "Buscar libretas de contactos globales y públicas para usuarios",
    "Allow users to publish their data to a global and public address book" : "Permitir a los usuarios publicar su información en la libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Puedes compartir con cualquiera que use un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM). Simplemente, pon su ID de Nube Federada en el diálogo de compartir. Es algo como persona@nube.ejemplo.com",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Add to your website" : "Añadir a su sitio web",
    "Share with me via Nextcloud" : "Compartirlo conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Has recibido \"/%3$s\" como un recurso compartido remoto de %1$s (en nombre de %2$s)",
    "You received \"%3$s\" as a remote share from %1$s" : "Has recibido \"%3$s\" como un compartido remoto de %1$s"
},
"nplurals=2; plural=(n != 1);");
